==> gnucash_2.4.10.orig.tar.bz2: gnucash-2.4.10/src/html/gnc-html-factory.c <==
/********************************************************************
 * gnc-html_factory.c -- Factory to create HTML component           *
 *                                                                  *
 * Copyright (C) 2009 Phil Longstaff <plongstaff@rogers.com>        *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
 * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 ********************************************************************/

#include "config.h"

#include <gtk/gtk.h>

#include "gnc-html.h"
#include "gnc-html-gtkhtml.h"
#include "gnc-html-webkit.h"
#include "qoflog.h"
#include "gnc-engine.h"

#include "gnc-html-factory.h"

/* indicates the debugging module that this .o belongs to.  */
static QofLogModule log_module = GNC_MOD_HTML;

GncHtml* gnc_html_factory_create_html( void )
{
#ifdef WANT_WEBKIT
    return gnc_html_webkit_new();
#else
    return gnc_html_gtkhtml_new();
#endif
}

gboolean
gnc_html_engine_supports_css( void )
{
#ifdef WANT_WEBKIT
    return TRUE;
#else
    return FALSE;
#endif
}

==> gnucash_2.6.18.orig.tar.bz2: gnucash-2.6.18/src/html/gnc-html-factory.c <==
/********************************************************************
 * gnc-html_factory.c -- Factory to create HTML component           *
 *                                                                  *
 * Copyright (C) 2009 Phil Longstaff <plongstaff@rogers.com>        *
 *                                                                  *
 * This program is free software; you can redistribute it and/or    *
 * modify it under the terms of the GNU General Public License as   *
 * published by the Free Software Foundation; either version 2 of   *
 * the License, or (at your option) any later version.              *
 *                                                                  *
 * This program is distributed in the hope that it will be useful,  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of   *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    *
 * GNU General Public License for more details.                     *
 *                                                                  *
 * You should have received a copy of the GNU General Public License*
 * along with this program; if not, contact:                        *
 *                                                                  *
 * Free Software Foundation           Voice:  +1-617-542-5942       *
 * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
 * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
 ********************************************************************/

#include "config.h"

#include <gtk/gtk.h>

#include "gnc-html.h"
#include "gnc-html-webkit.h"
#include "qoflog.h"
#include "gnc-engine.h"

#include "gnc-html-factory.h"

/* indicates the debugging module that this .o belongs to.  */
G_GNUC_UNUSED static QofLogModule log_module = GNC_MOD_HTML;

GncHtml* gnc_html_factory_create_html( void )
{
    return gnc_html_webkit_new();
}

gboolean
gnc_html_engine_supports_css( void )
{
    return TRUE;
}
